/* * Copyright 2021 Philippe Even, Université de Lorraine, IUT de St Dié.
 *     2023 Noémy Chevalier Contributor
 *     2023 Louise Berrada Contributor
 *     2023 Piquerez Corentin Contributor
 *
 *     This program is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

package shukan;
import javax.swing.*;
import java.awt.*;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;


/**
 * Shukan planner application.
 * Modified by Chevalier Noemy, Berrada Louise and Piquerez Corentin
 */
public class Shukan
{
    /** Shukan window top margin */
    private final static int TOP_MARGIN = 30;
    /** Shukan window left margin */
    private final static int LEFT_MARGIN = 50;

    /**
     * Creates AWT Frame with Shukan tools
     */
    public static void main (String[] args)
    {
        // Jikan data base creation and set up
        ShukanData data = new ShukanData ();
        ShukanIO io = new ShukanIO (data);


        // Handling edition mode
        if (args.length > 0)
            if (args[0].equals ("edit"))
            {
                new ShukanTex (data);
                System.exit (0);
            }

        // Creating Shukan viewer
        JFrame frame = new JFrame ("SHUKAN 1.6");
        JPanel global = new JPanel(new BorderLayout());
        ShukanView canvas = new ShukanView (data, io);
        ShukanViewBar mytoolbar = new ShukanViewBar(90);


        // Getting the display size
        GraphicsEnvironment ge = GraphicsEnvironment.getLocalGraphicsEnvironment ();
        GraphicsDevice gd = ge.getScreenDevices()[0];
        GraphicsConfiguration[] gc = gd.getConfigurations ();
        Rectangle gcBounds = gc[0].getBounds ();
        canvas.restrictSize ((int) (gcBounds.getWidth ()) - LEFT_MARGIN,
                (int) (gcBounds.getHeight ()) - TOP_MARGIN - mytoolbar.getHeight());
        mytoolbar.setSize(new Dimension((int) (gcBounds.getWidth ()) - LEFT_MARGIN, mytoolbar.getHeight()));


        // Adding a openGL input handler (controller)
        ShukanController myController = new ShukanController (canvas, mytoolbar, data);
        canvas.addKeyListener (myController);
        canvas.addMouseListener (myController);
        mytoolbar.addActionListener(myController);


        // Preparing the window closing button and adding a confirmation dialog 
        frame.addWindowListener(new WindowAdapter() {
            public void windowClosing(WindowEvent e) {
                int choix = JOptionPane.showConfirmDialog(frame, "Êtes-vous sûr de vouloir quitter ?", "Quitter", JOptionPane.YES_NO_OPTION);
                if (choix == JOptionPane.YES_OPTION) {
                    frame.dispose();
                    frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
                } else {
                    frame.setDefaultCloseOperation(JFrame.DO_NOTHING_ON_CLOSE);
                }
            }
        });
        


        // Setting the window geometry
        global.add(mytoolbar, BorderLayout.NORTH);
        global.add (canvas, BorderLayout.CENTER);
        //global.add(student, BorderLayout.SOUTH);
        frame.add(global);
        Insets ins = frame.getInsets ();
        frame.setSize (canvas.displayWidth () + ins.left + ins.right,
                canvas.displayHeight ()+ mytoolbar.getHeight()+ ins.top + ins.bottom );
        frame.setLocation (LEFT_MARGIN, 0);
        frame.setBackground (Color.white);
        frame.setVisible (true);

        // Triggering input handler loop
        canvas.requestFocus ();
    }
}
