/* * Copyright 2021 Philippe Even, Université de Lorraine, IUT de St Dié.
 *     2023 Noémy Chevalier Contributor
 *     2023 Louise Berrada Contributor
 *     2023 Piquerez Corentin Contributor
 *
 *     This program is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */
package shukan;


/**
 * Array list of Shukan elements
 * Modified by Chevalier Noemy, Berrada Louise and Piquerez Corentin
 */
public class ShukanList
{
  /** Default size of a created list */
  private final static int DEFAULT_SIZE = 10;

  /** Container of elements */
  private Object[] elts = null;
  /** Effective number of elements */
  private int count = 0;

  /** Creates a list with default size */
  public ShukanList ()
  {
    elts = new Object[DEFAULT_SIZE];
  }

  /** Creates a list with given size */
  public ShukanList (int size)
  {
    elts = new Object[size];
  }

  /** Empties the list */
  public void empty ()
  {
    count = 0;
  }

  /** Adds an object to the list */
  public void add (Object elt)
  {
    if (count == elts.length) doubleCapacity ();
    elts[count++] = elt;
  }

  /** Sets the list capacity to double size */
  private void doubleCapacity ()
  {
    Object[] tab = new Object[elts.length * 2];
    for (int i = 0; i < count; i++) tab[i] = elts[i];
    elts = tab;
  }

  /** Returns the number of objects in the list */
  public int size ()
  {
    return (count);
  }

  /** Removes an objects from the list */
  public void remove (Object elt)
  {
    for (int i = 0; i < count; i ++)
      if (elt == elts[i])
      {
        elts[i] = elts[--count];
	i = count + 1;
      }
  }

  /** Gets a copy of objects in the list */
  public void fill (Object[] objects)
  {
    for (int i = 0; i < count; i++)
      objects[i] = elts[i];
  }

  /** Returns an object of the list */
  public Object get (int index)
  {
    return (elts[index]);
  }

  /** Returns the last object of the list */
  public Object last ()
  {
    return (elts[count - 1]);
  }

  /** Returns the objects of the list */
  public Object[] toArray ()
  {
    Object[] obj = new Object[count];
    for (int i = 0; i < count; i++) obj[i] = elts[count];
    return (obj);
  }
}
