/* * Copyright 2021 Philippe Even, Université de Lorraine, IUT de St Dié.
 *     2023 Noémy Chevalier Contributor
 *     2023 Louise Berrada Contributor
 *     2023 Piquerez Corentin Contributor
 *
 *     This program is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

package shukan;


/**
 * Bidirectional queues of activities
 * Modified by Chevalier Noemy, Berrada Louise and Piquerez Corentin
 */
public class ShukanQueue
{
  /** Queue of activities */
  private int[] queue;
  /** Head position in the queue */
  private int head = 0;
  /** Number of actvities in the queue */
  private int length = 0;


  /** Creates a queue of given capacity */
  public ShukanQueue (int capa)
  {
    queue = new int[capa];
  }

  /** Neutralizes the queue */
  public void kill ()
  {
    queue = null;
    head = 0;
    length = 0;
  }

  /** delete the nth element in the queue */
  public void delete (int index){
    if (index<=queue.length){
      int tmp[] = new int[queue.length-1];
      for (int i =0; i<index; i++){
        tmp[i] = queue[i];
      }
      for (int i =index+1; i<queue.length; i++){
        tmp[i-1] = queue[i];
      }
      queue = tmp;
      length--;
    }
    else System.out.println("index trop grand");
  }

  /** remove 1 from an element of the queue */
  public void removeOne(int index){
    queue[index]--;
  }

  /** remove 1 from an element of the queue */
  public void removeAllOne(){
    if (queue != null){
      for (int i =0; i<queue.length; i++)queue[i]--;
    }

  }
  /** Pushes a token at the right of the queue */
  public void pushRight (int token)
  {
    if (queue != null && length < queue.length)
      queue[(head + length++) % queue.length] = token;
  }

  /** Pushes a token at the left of the queue */
  public void pushLeft (int token)
  {
    if (queue != null && length < queue.length)
    {
      if (--head < 0) head = queue.length - 1;
      queue[head] = token;
      length++;
    }
  }

  /** Returns the contents of the queue */
  public int[] contents ()
  {
    int[] contents = new int[length];
    for (int i = 0; i < length; i++)
      contents[i] = queue[(head + i) % queue.length];
    return (contents);
  }

  /** Returns the length of the queue */
  public int length ()
  {
    return (length);
  }

  /** Clears the queue */
  public void clear ()
  {
    length = 0;
  }

  /** Returns whether the queue is neutralized */
  public boolean killed ()
  {
    return (queue == null);
  }

  /** Returns whether the file is empty */
  public boolean empty ()
  {
    return (queue == null || length == 0);
  }

  /** Returns whether the file is full */
  public boolean full ()
  {
    return (queue == null || length == queue.length);
  }

  /** Withdraws and returns the head of the file */
  public int popLeft ()
  {
    int token = -1;
    if (length > 0 && length <= queue.length)
    {
      token = queue[head++];
      if (head == queue.length) head = 0;
      length --;
    }
    return (token);
  }

  /** Withdraws and returns the queue of the file */
  public int popRight ()
  {
    int token = -1;
     if (length > 0 && length <= queue.length)
      token = queue[(head + --length) % queue.length];
    return (token);
  }
}
