/* * Copyright 2021 Philippe Even, Université de Lorraine, IUT de St Dié.
 *     2023 Noémy Chevalier Contributor
 *     2023 Louise Berrada Contributor
 *     2023 Piquerez Corentin Contributor
 *
 *     This program is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

package shukan;

import javax.swing.*;
import javax.swing.border.LineBorder;
import java.awt.*;

/**
 * Barre d'outils de Shukan
 * Modified by Chevalier Noemy, Berrada Louise and Piquerez Corentin
 */
public class ShukanViewBar extends JPanel {

    /** Noms des fichiers d'images pour les boutons de la barre d'outils */
    private String[] imagesName = {"save", "back", "plus", "delete", "left", "right","change","semes","export", "parameter"};
    /** Boutons de la barre d'outils */
    protected JButton buttons[] = new JButton[10];
    /** Extension des images */
    private String imagesExtension = ".png";
    /** Hauteur en pixels de la barre d'outils */
    private int height;
    /** Barre contenant tous les boutons */
    private JPanel p_left, p_right;

    /** Construit la barre d'outils */
    public ShukanViewBar(int height) {
        p_left = new JPanel();
        p_right = new JPanel();

        this.height = height;

        for (int i = 0; i < imagesName.length; i++) {
            buttons[i] = new JButton("", new ImageIcon("data/images/" + imagesName[i] + imagesExtension));
            buttons[i].setPreferredSize(new Dimension(85, 85));
            buttons[i].setBackground(Color.WHITE);
            buttons[i].setBorder(new LineBorder(Color.WHITE));

            if (i < imagesName.length - 3)
                p_left.add(buttons[i]);
            else
                p_right.add(buttons[i]);
        }

        p_left.setBackground(Color.WHITE);
        p_right.setBackground(Color.WHITE);

        setLayout(new BorderLayout());
        add(p_left, BorderLayout.WEST);
        add(p_right, BorderLayout.EAST);

        setBackground(Color.WHITE);
    }

    /** Retourne la hauteur de la barre d'outils en pixels */
    public int getHeight() {
        return height;
    }

    /** Ajoute les actions pour les différents boutons */
    public void addActionListener(ShukanController controller) {
        for (int i = 0; i < imagesName.length; i++) {
            buttons[i].addActionListener(controller);
        }
    }
}
